Car = {}
function Car:load()
    self.spriteImage = love.graphics.newImage("assets/redCar.png")
    self.spriteInfo = {
      spriteWidth = self.spriteImage:getWidth(),
      spriteHeight = self.spriteImage:getHeight(),
      quadWidth = self.spriteImage:getWidth() / 9,
      quads = {}
    }
    self.animation = {
      direction = "right",
      idle = true,
      frame = 5,
      maxFrame = 8,
      speed = 30,
      timer = 0.1, 
    }
    self.degres = 0.0174532925199432957
    self.x = 150
    self.y = 400
    self.xVel = 0 
    self.yVel = 0 
    self.angle = -1.58 
    self.Friction = 3500
    self.max_speed = 120 
    self.accel = 400 
    self.deceleration = 350 -- deceleration force
    self.turnSpeed = math.rad(75) -- turning speed (in radians)
    self.nitroFuel = 360
    self.isNitro = false
    self.direction = "idle"
    self.isMoving = false
    self.speed = 0 -- current speed
    self.driftAngle = 0 -- current drift angle (in radians)
    self.driftFactor = 1.2 -- factor that affects drift behavior
    self.driftLoss = 100 -- speed loss during drift
    self.driftEnabled = false -- flag to enable/disable drift



    self.physics = {}
    self.physics.body = love.physics.newBody(World,self.x,self.y,"dynamic")
    self.physics.body:setAngle(self.angle)
    self.physics.shape = love.physics.newRectangleShape(self.spriteInfo.spriteWidth,self.spriteInfo.spriteHeight)
    self.physics.fixture = love.physics.newFixture(self.physics.body,self.physics.shape)
    --self.physics.fixture:setSensor(true)
    --self.physics.fixture = love.physics.newFixture(Tier.physics.body,Tier.physics.shape)

    for i = 1 ,self.animation.maxFrame do
      self.spriteInfo.quads[i] = love.graphics.newQuad(
          self.spriteInfo.quadWidth * (i - 1),
           0,
          self.spriteInfo.quadWidth,
          self.spriteInfo.spriteHeight,
          self.spriteInfo.spriteWidth,
          self.spriteInfo.spriteHeight)
  end

end

function Car:update(dt)
  self.x, self.y = self.physics.body:getPosition()
  self.physics.body:setLinearVelocity(self.xVel,self.yVel)

  if self.nitroFuel > 360 then
    self.nitroFuel = 360
  elseif self.nitroFuel < 0 then
    self.nitroFuel = 0
  end

   -- Player controls
  if Joystick.isActive then
       normalizedX = (Joystick.handleX - Joystick.x)
       normalizedY = (Joystick.handleY - Joystick.y)  
      self.angle = math.atan2(normalizedY, normalizedX)
      self.speed = self.max_speed * math.sqrt(normalizedX ^ 2 + normalizedY ^ 2) 
  else
      self.speed = 0
  end

  -- Car movement
  if Joystick.isActive then
    local dx = self.speed * math.cos(self.angle) * dt
    local dy = self.speed * math.sin(self.angle) * dt
    self.xVel = self.xVel + dx
    self.yVel = self.yVel + dy
    self.physics.body:setLinearVelocity(self.xVel,self.yVel)
  else
    --self.speed = 0
    

    if self.xVel > 0 then
      if self.xVel - self.Friction * dt > 0 then
          self.xVel = self.xVel - self.Friction * dt
      else
          self.xVel = 0
      end
    elseif self.xVel < 0 then
          if self.xVel + self.Friction * dt < 0 then
              self.xVel = self.xVel + self.Friction * dt
          else
              self.xVel = 0
          end
      end 
    end

    if self.yVel > 0 then
      if self.yVel - self.Friction * dt > 0 then
          self.yVel = self.yVel - self.Friction * dt
      else
          self.yVel = 0
      end
    elseif self.yVel < 0 then
        if self.yVel + self.Friction * dt < 0 then
              self.yVel = self.yVel + self.Friction * dt
        else
              self.yVel = 0
        end
    end 
  
  
  if  self.angle >= 450 then
    self.angle = 0
    self.physics.body:setAngle(self.angle * self.degres)
  elseif self.angle <= -270 then
    self.angle = 0
    self.physics.body:setAngle(self.angle * self.degres)
  end


  speed = math.sqrt(self.xVel^2 + self.yVel^2)
  if speed > self.max_speed then
    self.xVel = self.xVel * self.max_speed / speed
    self.yVel = self.yVel * self.max_speed / speed
  end
  
  -- apply friction / air resistance
   self.xVel = self.xVel * 0.99
   self.yVel = self.yVel * 0.99
   self.physics.body:setAngle(self.angle)

end

function Car:draw()
     -- draw car
  --love.graphics.print("xVel"..self.xVel,500,0)
  --love.graphics.print("yVel"..self.yVel,500,20)
 -- love.graphics.print("angle"..self.angle,500,40)
 -- love.graphics.print("direction "..self.direction,500,60)
 -- love.graphics.print("speed "..self.speed,500,80)
  normalizedX = (Joystick.handleX - Joystick.x) / (Joystick.radius - Joystick.handleRadius)
  normalizedY = (Joystick.handleY - Joystick.y) / (Joystick.radius - Joystick.handleRadius)
 -- love.graphics.print("normalizedX "..normalizedX,500,100)
 -- love.graphics.print("normalizedY "..normalizedY,500,120)
 -- love.graphics.print("angle "..self.angle,500,140)




 -- love.graphics.print("quads"..self.animation.frame,500,80)
  --love.graphics.print("speed"..speed,500,80)
  love.graphics.polygon("line", self.physics.body:getWorldPoints(self.physics.shape:getPoints())) 
  love.graphics.draw(self.spriteImage,self.x ,self.y,self.angle,1,1,25,13)
  -- Draw car direction indicator
  --local indicatorX = self.x + math.cos(self.angle) * 30
 -- local indicatorY = self.y + math.sin(self.angle) * 30
  --love.graphics.setColor(1, 1, 1) -- Set color to white
 -- love.graphics.line(self.x, self.y, indicatorX, indicatorY)
  
end



function Car:beginContact(a,b,collision)
  
  
end

function Car:endContact(a,b,collision)
 
end